from tkinter.ttk import Widget
from tkscrollutil.load import load_tile
from tkscrollutil.attrib import Attrib


class ScrollSync(Widget, Attrib):
    def __init__(self, master=None, cnf={}, **kw):
        """
        STANDARD OPTIONS

            activebackground, activeforeground, anchor,
            background, bitmap, borderwidth, cursor,
            disabledforeground, font, foreground
            highlightbackground, highlightcolor,
            highlightthickness, image, justify,
            padx, pady, relief, repeatdelay,
            repeatinterval, takefocus, text,
            textvariable, underline, wraplength

        """
        try:
            load_tile(master)
        except:
            from tkinter import _default_root
            load_tile(_default_root)
        Widget.__init__(self, master, "scrollutil::scrollsync", kw, )

    def setwidgets(self, widgetList: list):
        return self.tk.call(self._w, "setwidgets", widgetList)


if __name__ == '__main__':
    from tkinter import Tk, Listbox, Frame
    from tkscrollutil import ttkScrollArea
    root = Tk()

    frame = Frame()

    area = ttkScrollArea(frame, yscrollbarmode="static")
    sync = ScrollSync(area)
    area.setwidget(sync)

    area.pack(fill="y", side="right")

    list1 = Listbox()
    list1.pack(fill="both", side="left", expand="yes")
    list2 = Listbox()
    list2.pack(fill="both", side="right", expand="yes")

    for item in range(300):
        list1.insert(item, item)
        list2.insert(item, item)

    sync.setwidgets([list1, list2])

    frame.pack(fill="both", expand="yes")

    root.mainloop()


from tkinter import Tk, Widget, Listbox
from tkscrollutil.scrollarea import ScrollArea
from tkscrollutil.scrollsync import ScrollSync
from tkscrollutil.ttk_scrollarea import ScrollArea as ttkScrollArea
from tkscrollutil.ttk_scrollsync import ScrollSync as ttkScrollSync
from tkscrollutil.ttk_scrollednotebook import ScrolledNoteBook as ttkScrolledNoteBook
from tkscrollutil.wheelevent import addMouseWheelSupport, createWheelEventBindings, \
    enableScrollingByWheel, disableScrollingByWheel, \
    adaptWheelEventHandling, setFocusCheckWindow, \
    focusCheckWindow, addclosetab
from tkscrollutil.load import load, load_tile


__all__ = [
    "load",
    "load_tile",
    "ScrollArea",
    "ScrollSync",
    "ttkScrollArea",
    "ttkScrollSync",
    "addMouseWheelSupport",
    "createWheelEventBindings",
    "enableScrollingByWheel",
    "disableScrollingByWheel",
    "adaptWheelEventHandling",
    "setFocusCheckWindow",
    "focusCheckWindow",
    "addclosetab"
]

STATIC = "static"
DYNAMIC = "dynamic"
NONE = "none"



from tkinter import Widget
from tkscrollutil.load import load
from tkscrollutil.attrib import Attrib


class ScrollLabelFrame(Widget, Attrib):
    def __init__(self, master=None, cnf={}, **kw):
        """
        STANDARD OPTIONS

            activebackground, activeforeground, anchor,
            background, bitmap, borderwidth, cursor,
            disabledforeground, font, foreground
            highlightbackground, highlightcolor,
            highlightthickness, image, justify,
            padx, pady, relief, repeatdelay,
            repeatinterval, takefocus, text,
            textvariable, underline, wraplength

        WIDGET-SPECIFIC OPTIONS

            contentheight
            contentwidth
            fitcontentheight
            fitcontentwidth
            height
            takefocus
            width screenDistance
            xscrollincrement
            yscrollincrement

        """
        try:
            load(master)
        except:
            from tkinter import _default_root
            load(_default_root)
        Widget.__init__(self, master, "scrollutil::scrollableframe", cnf, kw, )

    def contentframe(self):
        frame = self.tk.call(self._w, "contentframe")
        return frame


if __name__ == '__main__':
    from tkinter import Tk, Label
    from tkscrollutil.scrollarea import ScrollArea
    from tkscrollutil.wheelevent import createWheelEventBindings
    root = Tk()

    area = ScrollArea(root, yscrollbarmode="static")
    frame = ScrollLabelFrame(area)
    area.setwidget(frame)

    context = frame.contentframe()

    createWheelEventBindings()

    for item in range(10):
        Label(context, text=str(item)).pack()

    area.pack(fill="both", expand="yes")

    root.mainloop()


from tkinter.ttk import Widget, Notebook
from tkscrollutil.load import load_tile
from tkscrollutil.attrib import Attrib


class ScrolledNoteBook(Attrib, Notebook):
    def __init__(self, master=None, cnf={}, **kw):
        """
        STANDARD OPTIONS

            activebackground, activeforeground, anchor,
            background, bitmap, borderwidth, cursor,
            disabledforeground, font, foreground
            highlightbackground, highlightcolor,
            highlightthickness, image, justify,
            padx, pady, relief, repeatdelay,
            repeatinterval, takefocus, text,
            textvariable, underline, wraplength

        """
        try:
            load_tile(master)
        except:
            from tkinter import _default_root
            load_tile(_default_root)
        Widget.__init__(self, master, "scrollutil::scrollednotebook", kw)


if __name__ == '__main__':
    from tkinter import Tk, Frame
    from tkscrollutil import ttkScrolledNoteBook, addclosetab
    root = Tk()

    notebook = ttkScrolledNoteBook()

    addclosetab("TNotebook")

    notebook.add(Frame(notebook), text="Hello World")
    notebook.pack(fill="both", expand="yes")

    root.mainloop()


import contextlib
import os


@contextlib.contextmanager
def chdir(target: str):
    """Context-managed chdir, original implementation by GitHub @Akuli"""
    current = os.getcwd()
    try:
        os.chdir(target)
        yield
    finally:
        os.chdir(current)


def load(window, version: str = ""):
    global _load_scrollutil
    local = os.path.abspath(os.path.dirname(__file__))
    with chdir(local):
        window.tk.eval("set dir [file dirname [info script]]")
        window.tk.eval("source pkgIndex.tcl")
        window.tk.eval("package require scrollutil " + version)


def load_tile(window, version: str = ""):
    global _load_scrollutil_tile
    local = os.path.abspath(os.path.dirname(__file__))
    with chdir(local):
        window.tk.eval("set dir [file dirname [info script]]")
        window.tk.eval("source pkgIndex.tcl")
        window.tk.eval("package require scrollutil_tile " + version)



from tkinter import Widget
from tkscrollutil.load import load
from tkscrollutil.attrib import Attrib


class ScrollArea(Widget, Attrib):
    def __init__(self, master=None, cnf={}, **kw):
        """The command creates a new window named and of the class , and makes it into a scrollarea widget.
        Additional options, described below, may be specified on the command line or in the option database to configure aspects of the scrollarea such as its borderwidth, relief, and display mode to be used for the scrollbars.
        The command returns its argument.
        At the time this command is invoked, there must not exist a window named , but 's parent must exist.scrollutil::scrollareapathNameScrollareascrollutil::scrollareapathNamepathNamepathName

        STANDARD OPTIONS

            activebackground, activeforeground, anchor,
            background, bitmap, borderwidth, cursor,
            disabledforeground, font, foreground
            highlightbackground, highlightcolor,
            highlightthickness, image, justify,
            padx, pady, relief, repeatdelay,
            repeatinterval, takefocus, text,
            textvariable, underline, wraplength

        WIDGET-SPECIFIC OPTIONS

            autohidescrollbars, lockinterval,
            respectheader, respecttitlecolumns, setfocus, xscrollbarmode, yscrollbarmode

        """
        try:
            load(master)
        except:
            from tkinter import _default_root
            load(_default_root)
        Widget.__init__(self, master, "scrollutil::scrollarea", cnf, kw, )

    def setwidget(self, widget: Widget = ""):
        return self.tk.call(self._w, "setwidget", widget)


if __name__ == '__main__':
    from tkinter import Tk, Listbox
    root = Tk()

    area = ScrollArea(root, lockinterval=30000)
    list = Listbox(area)
    for item in range(30):
        list.insert(item+1, item+1)
    area.setwidget(list)
    area.pack(fill="both", expand="yes")

    root.mainloop()


def addMouseWheelSupport(tag="all"):
    from tkinter import _default_root
    _default_root.eval("scrollutil::addMouseWheelSupport "+tag)

def createWheelEventBindings(tag="all"):
    from tkinter import _default_root
    _default_root.eval("scrollutil::createWheelEventBindings "+tag)

def enableScrollingByWheel(scrollableWidgetContainer=""):
    from tkinter import _default_root
    _default_root.eval("scrollutil::enableScrollingByWheel "+scrollableWidgetContainer)

def disableScrollingByWheel(scrollableWidgetContainer=""):
    from tkinter import _default_root
    _default_root.eval("scrollutil::disableScrollingByWheel "+scrollableWidgetContainer)

def adaptWheelEventHandling(ignorefocus="", widget=""):
    from tkinter import _default_root
    _default_root.eval("scrollutil::adaptWheelEventHandling "+ignorefocus+" "+widget)

def setFocusCheckWindow(widget=""):
    from tkinter import _default_root
    _default_root.eval("scrollutil::setFocusCheckWindow "+widget)

def focusCheckWindow(widget=""):
    from tkinter import _default_root
    _default_root.eval("scrollutil::focusCheckWindow "+widget)

def addclosetab(style):
    from tkinter import _default_root
    _default_root.eval("scrollutil::addclosetab "+style)

def removeclosetab(style):
    from tkinter import _default_root
    _default_root.eval("scrollutil::removeclosetab "+style)


from setuptools import find_packages, setup

setup(
    name="tkscrollutil",
    version="1.3.117",
    author="XiangQinxi",
    author_email="XiangQinxi@outlook.com",
    description="tkinter scroll extra",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    python_requires=">=3",
    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests"]),
    package_data={"": ["*.tcl"], "scripts": ["*", "tclIndex"], "scripts/utils": ["*"]},
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



class Attrib(object):
    def attrib(self, name=None, value=None):
        return self.tk.call(self._w, "attrib", name, value)

    def hasattrib(self, name=None):
        has = self.tk.call(self._w, "hasattrib", name)
        if has == 1:
            return True
        else:
            return False

    def unsetattrib(self, name=None):
        return self.tk.call(self._w, "unsetattrib", name)
